import QtQuick 1.0

Rectangle {
    id: editorialsDetail
    state: "hideLeft"

    //------------- Internal Globle Variable --------------------------
    property int i: 0

    //------------- Pages Moving Animation Control --------------------
    function showPageFromLeft()
    {
        editorialsDetail.state = "";
        editorialsDetail.state = "hideLeft"
        editorialsDetail.state = "show"
    }

    function showPageFromRight()
    {
        editorialsDetail.state = "";
        editorialsDetail.state = "hideRight"
        editorialsDetail.state = "show"
    }

    function hidePageToLeft()
    {
        editorialsDetail.state = "";
        editorialsDetail.state = "show"
        editorialsDetail.state = "hideLeft"
    }

    function hidePageToRight()
    {
        editorialsDetail.state = "";
        editorialsDetail.state = "show"
        editorialsDetail.state = "hideRight"
    }
    //----------------------- End ---------------------------------------

    function receiveData(uid, name, section, description, imageUrl)
    {
        loadingCover.hideLoadingCover();

        textFlick.opacity = 1;

        titleText.text = name;
        subTitleText.text = section;
        mainImage.source = imageUrl;
        edit.text = description;
    }

    Timer {
        id: resetTimer
        interval: 300; running: false; repeat: false
        onTriggered: doResetData();
    }

    function resetData()
    {
        resetTimer.running = true;
    }

    function doResetData()
    {
        titleText.text = "";
        subTitleText.text = "";
        mainImage.source = "";
        edit.text = "";
        textFlick.opacity = 0;
    }

    Flickable {
        id: textFlick
        x: 0
        y: 10 * glValue.appUIWidth / 360
        width: 360 * glValue.appUIWidth / 360;
        height: restaurantsDetail.height;
        contentWidth: 360 * glValue.appUIWidth / 360
        contentHeight: edit.height + edit.y + 15
        flickableDirection: Flickable.VerticalFlick
        clip: true
        opacity: 0

        Text {
            id: titleText
            x: 10 * glValue.appUIWidth / 360
            y: 10 * glValue.appUIHeight / 640
            width: 340 * glValue.appUIWidth / 360
            height: 40 * glValue.appUIHeight / 640
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: 40
            font.bold: true
            wrapMode: "WordWrap"
            text: ""
        }

        Text {
            id: subTitleText
            x: 10 * glValue.appUIWidth / 360
            y: titleText.paintedHeight + titleText.y - 0 * glValue.appUIHeight / 640
            width: 340 * glValue.appUIWidth / 360
            height: subTitleText.paintedHeight * glValue.appUIHeight / 640
            verticalAlignment: Text.AlignTop
            font.pixelSize: 25
            wrapMode: "WordWrap"
            text: ""
        }

        Image {
            id: line_1
            x: 8 * glValue.appUIWidth / 360
            y: subTitleText.height + subTitleText.y + 5
            width: 344 * glValue.appUIWidth / 360
            height: 5 * glValue.appUIHeight / 640
            source: "images/line.png"
        }

        Image {
            id: mainImage
            x: 0
            y: line_1.y + line_1.height + 8
            width: 360 * glValue.appUIWidth / 360
            height: (360/1.6667) * glValue.appUIHeight / 640
            source: ""
            state: "hide"

            states:
            [
                State
                {
                    name: "show"
                    PropertyChanges { target: mainImage; opacity: 1 }
                },
                State
                {
                    name: "hide"
                    PropertyChanges { target: mainImage; opacity: 0 }
                }
            ]
            transitions:
            [
                Transition {
                    from: "hide"; to: "show"
                    PropertyAnimation { properties: "opacity"; duration: 500; easing.type: Easing.InOutQuad }
                }
            ]

            onStatusChanged: {
                if(mainImage.status == 2) {
                    mainImageBusy.opacity = 0.8
                    rotation.running = true
                }
                else if(mainImage.status == 1) {
                    mainImageBusy.opacity = 0
                    rotation.running = false
                    mainImage.state = "show"
                }
            }
        }

        Image {
            id: mainImageBusy
            anchors.centerIn: mainImage
            width: 35 * glValue.appUIWidth / 360
            height: 35 * glValue.appUIHeight / 640
            smooth: true
            opacity: 1
            source: "images/busy.png"

            RotationAnimation on rotation {
                id: rotation
                loops: 10000
                from: 0
                to: 360
                duration: 1200
            }
        }

        TextEdit {
            id: edit
            x: 8 * glValue.appUIWidth / 360
            y: mainImage.height + mainImage.y
            width: 344 * glValue.appUIWidth / 360
            height: edit.paintedHeight
            wrapMode: TextEdit.Wrap
            readOnly: true
            font.pixelSize: 25
            focus: false
            text: ""
        }
    }

    states:
    [
        State
        {
            name: "show"
            PropertyChanges { target: editorialsDetail; x: 0; opacity: 1 }
        },
        State
        {
            name: "hideLeft"
            PropertyChanges { target: editorialsDetail; x: -editorialsDetail.width; opacity: 1 }
        },
        State
        {
            name: "hideRight"
            PropertyChanges { target: editorialsDetail; x: editorialsDetail.width; opacity: 1 }
        }
    ]
    transitions:
    [
        Transition {
            from: "show"; to: "hideLeft"
            PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
        },
        Transition {
            from: "hideLeft"; to: "show"
            PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
        },
        Transition {
            from: "show"; to: "hideRight"
            PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
        },
        Transition {
            from: "hideRight"; to: "show"
            PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
        }
    ]
}
