import QtQuick 1.0

Item {
    id: editorialsPage
    state: "hideLeft"

    //------------- Internal Globle Variable --------------------------
    property int i: 0

    //------------- Pages Moving Animation Control --------------------
    function showPageFromLeft()
    {
        editorialsPage.state = "";
        editorialsPage.state = "hideLeft"
        editorialsPage.state = "show"
    }

    function showPageFromRight()
    {
        editorialsPage.state = "";
        editorialsPage.state = "hideRight"
        editorialsPage.state = "show"
    }

    function hidePageToLeft()
    {
        editorialsPage.state = "";
        editorialsPage.state = "show"
        editorialsPage.state = "hideLeft"
    }

    function hidePageToRight()
    {
        editorialsPage.state = "";
        editorialsPage.state = "show"
        editorialsPage.state = "hideRight"
    }

    function receiveGeneralData(uid, name, section, imageUrl,
                                apiUrl, webUrl)
    {
        topTenPageListModel.append(
                        {"elementID": topTenPageListModel.count,
                         "elementUid": uid,
                         "elementName": name,
                         "elementSection": section,
                         "elementImageUrl": imageUrl,
                         "elementApiUrl": apiUrl,
                         "elementWebUrl": webUrl})
    }

    signal requireEditorialsDetail(string apiUrl)

    Item {
        id: pageContent
        x: 0
        y: 0
        width: parent.width
        height: parent.height

        Item {
            id: listContainer
            x: 14 * glValue.appUIWidth / 360
            y: 80 * glValue.appUIHeight / 640
            width: 332 * glValue.appUIWidth / 360
            height: pageContent.height - 80 - 15 * glValue.appUIHeight / 640

            ListModel {
                id: topTenPageListModel
            }

            Component {
                id: topTenPageComponent

                Item {
                    id: topTenPageDelegateItem
                    width: topTenPageListView.width
                    height: 70 * glValue.appUIHeight / 640
                    smooth: true

                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            if(elementSection == "Film")
                            {
                                if(editorialsFilmDetail.status == Loader.Null)
                                    editorialsFilmDetail.source = "FilmDetail.qml"

                                editorialsFilmDetail.item.resetData()
                                editorialsFilmDetail.item.fromWhichPage = "editorials";

                                editorialsFilmDetail.item.showPageFromRight();
                                editorialsPage.hidePageToLeft();

                                editorialsFilmDetail.item.getFilmData(elementApiUrl);

                                glValue.currentPage = "editorialsFilmDetail"
                                glValue.homeCurrentPage = "editorialsFilmDetail"
                            }
                            else
                            {
                                loadingCover.showLoadingCover();

                                requireEditorialsDetail(elementApiUrl);
                                homePage.hidePageToLeft();
                                editorialsDetail.showPageFromRight();
                                topBar.showBackButton()

                                glValue.currentPage = "editorialsDetail"
                                glValue.homeEditorialsCurrentPage = "editorialsDetail"
                            }
                        }
                    }

                    Image {
                        anchors.fill: parent
                        source: "images/listBGFull.png"
                    }

                    Image {
                        id: mainImage
                        x: 0
                        y: 0
                        width: 90 * glValue.appUIWidth / 360
                        height: 65 * glValue.appUIHeight / 640
                        fillMode: Image.PreserveAspectCrop
                        clip: true
                        source: elementImageUrl
                        state: "hide"

                        states:
                        [
                            State
                            {
                                name: "show"
                                PropertyChanges { target: mainImage; opacity: 1 }
                            },
                            State
                            {
                                name: "hide"
                                PropertyChanges { target: mainImage; opacity: 0 }
                            }
                        ]
                        transitions:
                        [
                            Transition {
                                from: "hide"; to: "show"
                                PropertyAnimation { properties: "opacity"; duration: 500; easing.type: Easing.InOutQuad }
                            }
                        ]

                        onStatusChanged: {
                            if(mainImage.status == 2) {
                                mainImageBusy.opacity = 0.8
                                rotation.running = true
                            }
                            else if(mainImage.status == 1) {
                                mainImageBusy.opacity = 0
                                rotation.running = false
                                mainImage.state = "show"
                            }
                        }
                    }

                    Image {
                        id: mainImageBusy
                        anchors.centerIn: mainImage
                        width: 25
                        height: 25
                        smooth: true
                        opacity: 1
                        source: "images/busy.png"

                        RotationAnimation on rotation {
                            id: rotation
                            loops: 10000
                            from: 0
                            to: 360
                            duration: 1200
                        }
                    }

                    Text {
                        anchors.fill: parent
                        anchors.leftMargin: 100 * glValue.appUIWidth / 360
                        anchors.rightMargin: 40 * glValue.appUIWidth / 360
                        verticalAlignment: Text.AlignVCenter
                        wrapMode: "WordWrap"
                        font.pixelSize: 30
                        opacity: 0.9
                        color: "white"
                        text: elementName
                    }

                    Image {
                        x: 300 * glValue.appUIWidth / 360
                        y: 18 * glValue.appUIHeight / 640
                        width: 27 * glValue.appUIWidth / 360
                        height: 32 * glValue.appUIHeight / 640
                        source: "images/arrow.png"
                    }

                    Image {
                        x: 0
                        y: 65 * glValue.appUIHeight / 640
                        width: parent.width
                        height: 5 * glValue.appUIHeight / 640
                        opacity: 1

                        source: "images/listLine.png"
                    }
                }
            }

            ListView {
                id: topTenPageListView
                anchors.fill: parent
                model: topTenPageListModel
                delegate: topTenPageComponent
                cacheBuffer: 70 * 10 * glValue.appUIHeight / 640
            }
        }

        Image {
            x: 0
            y: 0
            width: 360 * glValue.appUIWidth / 360
            height: 80 * glValue.appUIHeight / 640
            source: "images/filtlerBGBG.png"
        }

        Image {
            id: abc
            x: 14 * glValue.appUIWidth / 360
            y: 15 * glValue.appUIHeight / 640
            width: 332 * glValue.appUIWidth / 360
            height: 49 * glValue.appUIHeight / 640
            source: "images/filtlerBG.png"

            Text {
                anchors.fill: parent
                anchors.leftMargin: 15 * glValue.appUIWidth / 360
                verticalAlignment: Text.AlignVCenter
                font.pixelSize: 30
                font.bold: true
                color: "white"
                opacity: 0.8
                text: "Trending"
            }
        }

        Image {
            x: 14 * glValue.appUIWidth / 360
            y: 80 * glValue.appUIHeight / 640
            width: 25 * glValue.appUIWidth / 360
            height: 25 * glValue.appUIHeight / 640
            source: "images/topTenPageImageLeftConner.png"
        }
    }

    states:
    [
        State
        {
            name: "show"
            PropertyChanges { target: editorialsPage; x: 0; opacity: 1 }
        },
        State
        {
            name: "hideLeft"
            PropertyChanges { target: editorialsPage; x: -editorialsPage.width; opacity: 1 }
        },
        State
        {
            name: "hideRight"
            PropertyChanges { target: editorialsPage; x: editorialsPage.width; opacity: 1 }
        }
    ]
    transitions:
    [
        Transition {
            from: "show"; to: "hideLeft"
            PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
        },
        Transition {
            from: "hideLeft"; to: "show"
            PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
        },
        Transition {
            from: "show"; to: "hideRight"
            PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
        },
        Transition {
            from: "hideRight"; to: "show"
            PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
        }
    ]
}
