import QtQuick 1.0

Rectangle {
    id: homePage
    state: "hideLeft"

    //------------- Internal Globle Variable --------------------------
    property int i: 0

    //------------- Pages Moving Animation Control --------------------
    function showPageFromLeft()
    {
        pageContent.state = "";
        pageContent.state = "hideLeft"
        pageContent.state = "show"
    }

    function showPageFromRight()
    {
        pageContent.state = "";
        pageContent.state = "hideRight"
        pageContent.state = "show"
    }

    function hidePageToLeft()
    {
        pageContent.state = "";
        pageContent.state = "show"
        pageContent.state = "hideLeft"
    }

    function hidePageToRight()
    {
        pageContent.state = "";
        pageContent.state = "show"
        pageContent.state = "hideRight"
    }
    //----------------------- End ---------------------------------------

    //-------------- Append Home Page Images List Model -----------------
    function appendImageList(uid, name, section, imageUrl, apiUrl, webUrl)
    {
        homePageImageModel.append({
            "elementID": homePageImageModel.count,
            "elementUid": uid,
            "elementName": name,
            "elementSection": section,
            "elementImageUrl": imageUrl,
            "elementApiUrl": apiUrl,
            "elementWebUrl": webUrl,
        })

        pagniationListModel.append({
            "elementID": pagniationListModel.count,
            "elementSelected": !(pagniationListModel.count),
            "elementImage": "images/pagniationUnSelected.png",
            "elementImageSelected": "images/pagniationSelected.png"
        })

        editorialsPage.receiveGeneralData(uid, name, section, imageUrl, apiUrl, webUrl);
    }

    signal requireEditorialsDetail(string apiUrl)

    Item {
        id: pageContent
        x: 0
        y: 0
        width: parent.width
        height: parent.height

        Image {
            x: 0
            y: -topBar.height
            width: parent.width
            height: glValue.appUIHeight
            source: "images/welcomeBG.png"
        }

        Item {
            id: container
            x: 0
            y: 0
            width: parent.width
            height: parent.height

            ListModel {
                id: homePageListModel

                ListElement {
                    elementID: 0
                    elementName: "Restaurants"
                    elementImage: "images/listBGFull.png"
                    elementLineOpacity: 1
                    elementSelectedOpacity: 0
                }
                ListElement {
                    elementID: 1
                    elementName: "Bars & Clubs"
                    elementImage: "images/listBGFull.png"
                    elementLineOpacity: 1
                    elementSelectedOpacity: 0
                }
                ListElement {
                    elementID: 2
                    elementName: "Nightlife & Music"
                    elementImage: "images/listBGFull.png"
                    elementLineOpacity: 1
                    elementSelectedOpacity: 0
                }
                ListElement {
                    elementID: 3
                    elementName: "Films"
                    elementImage: "images/listBGFull.png"
                    elementLineOpacity: 1
                    elementSelectedOpacity: 0
                }
                ListElement {
                    elementID: 4
                    elementName: "Hotels"
                    elementImage: "images/listBGFull.png"
                    elementLineOpacity: 1
                    elementSelectedOpacity: 0
                }
                ListElement {
                    elementID: 5
                    elementName: "Trending"
                    elementImage: "images/listBGBottom.png"
                    elementLineOpacity: 0
                    elementSelectedOpacity: 0
                }
            }

            Component {
                id: homePageComponent

                Item {
                    id: homePageDelegateItem
                    width: homePageListView.width
                    height: 65 * glValue.appUIHeight / 640
                    smooth: true

                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            //------------- Reset and Highlight UI Selection ----------------------
                            for(i=0; i<homePageListModel.count; i++)
                            {
                                homePageListModel.get(i).elementSelectedOpacity = 0;
                            }
                            homePageListModel.get(elementID).elementSelectedOpacity = 1;

                            //-------------- Setting Global Value ---------------------------------
                            glValue.firstLevelSelection = elementName;
                            glValue.currentPage = "homePageParentFilter";
                            glValue.homeCurrentPage = "homePageParentFilter";

                            //-------------- Setting Second Level List Model ----------------------
                            homePageParentFilter.clearListModel();

                            if(elementName == "Restaurants") {
                                homePageParentFilter.appendListModelRestaurants();
                            }
                            else if(elementName == "Bars & Clubs") {
                                homePageParentFilter.appendListModelBarsClubs();
                            }
                            else if(elementName == "Nightlife & Music") {
                                homePageParentFilter.appendListModelNightliseMusic();
                            }
                            else if(elementName == "Films") {
                                homePageParentFilter.appendListModelFilm();
                            }
                            else if(elementName == "Hotels") {
                                homePageParentFilter.appendListModelHotel();
                            }

                            //-------------- Reset All Special Filters Selection Values -----------
                            homePageSpecialFilter.resetAllValues();

                            //-------------- Animate UI -------------------------------------------
                            topBar.showBackButton();

                            homePage.hidePageToLeft();

                            if(elementName == "Trending") {
                                glValue.homeCurrentPage = "editorialsPage";

                                editorialsPage.showPageFromRight();

                                glValue.currentPage = "editorialsPage";
                                glValue.homeCurrentPage = "editorialsPage";
                            }
                            else
                                homePageParentFilter.showPageFromRight();

                        }
                    }

                    Image {
                        x: 0
                        y: 0
                        width: parent.width
                        height: 60 * glValue.appUIHeight / 640
                        source: elementImage
                    }

                    Image {
                        id: homePageListSelectedImage
                        x: 0
                        y: 0
                        width: parent.width
                        height: 60 * glValue.appUIHeight / 640
                        opacity: elementSelectedOpacity
                        source: "images/listBGSelected.png"
                    }

                    Image {
                        x: 295 * glValue.appUIWidth / 360
                        y: 16 * glValue.appUIHeight / 640
                        width: 27 * glValue.appUIWidth / 360
                        height: 32 * glValue.appUIHeight / 640
                        source: "images/arrow.png"
                    }

                    Text {
                        anchors.fill: parent
                        anchors.leftMargin: 15 * glValue.appUIWidth / 360
                        verticalAlignment: Text.AlignVCenter
                        font.pixelSize: 40
                        color: "white"
                        text: elementName
                    }

                    Image {
                        x: 0
                        y: 60 * glValue.appUIHeight / 640
                        width: parent.width
                        height: 5 * glValue.appUIHeight / 640
                        opacity: elementLineOpacity
                        source: "images/listLine.png"
                    }
                }
            }

            ListView {
                id: homePageListView
                x: 14 * glValue.appUIWidth / 360
                y: 245 * glValue.appUIHeight / 640
                width: 332 * glValue.appUIWidth / 360
                height: parent.height - ((217 + 31)  * glValue.appUIWidth / 360)
                model: homePageListModel
                delegate: homePageComponent
                clip: true
            }

            ListModel {
                id: homePageImageModel
            }

            Component {
                id: homePageImageComponent

                Item {
                    id: homePageImageDelegateItem
                    width: homePageImageListView.width
                    height: 217 * glValue.appUIHeight / 640
                    smooth: true

                    Item {
                        anchors.fill: parent

                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                if(elementSection == "Film")
                                {
                                    if(editorialsFilmDetail.status == Loader.Null)
                                        editorialsFilmDetail.source = "FilmDetail.qml"

                                    editorialsFilmDetail.item.resetData()
                                    editorialsFilmDetail.item.fromWhichPage = "home";

                                    editorialsFilmDetail.item.showPageFromRight();
                                    homePage.hidePageToLeft();

                                    topBar.showBackButton();

                                    editorialsFilmDetail.item.getFilmData(elementApiUrl);

                                    glValue.currentPage = "editorialsFilmDetail"
                                    glValue.homeCurrentPage = "editorialsFilmDetail"
                                }
                                else
                                {
                                    loadingCover.showLoadingCover();

                                    requireEditorialsDetail(elementApiUrl);
                                    homePage.hidePageToLeft();
                                    editorialsDetail.showPageFromRight();
                                    topBar.showBackButton()

                                    glValue.currentPage = "editorialsDetail"
                                    glValue.homeEditorialsCurrentPage = "editorialsDetail"
                                }
                            }
                        }

                        Image {
                            id: homePageImage
                            anchors.fill: parent
                            state: "hide"
                            source: elementImageUrl
                            onStatusChanged: {
                                if(homePageImage.status == 1) {
                                    mainImageBusy.opacity = 0
                                    rotation.running = false
                                    homePageImage.state = "show"
                                }
                                else {
                                    mainImageBusy.opacity = 0.8
                                    rotation.running = true
                                }
                            }

                            states:
                            [
                                State
                                {
                                    name: "show"
                                    PropertyChanges { target: homePageImage; opacity: 1 }
                                },
                                State
                                {
                                    name: "hide"
                                    PropertyChanges { target: homePageImage; opacity: 0 }
                                }
                            ]
                            transitions:
                            [
                                Transition {
                                    from: "hide"; to: "show"
                                    PropertyAnimation { properties: "opacity"; duration: 500; easing.type: Easing.InOutQuad }
                                }
                            ]
                        }

                        Image {
                            id: mainImageBusy
                            anchors.centerIn: homePageImage
                            width: 35
                            height: 35
                            smooth: true
                            opacity: 1
                            source: "images/busy.png"

                            RotationAnimation on rotation {
                                id: rotation
                                loops: 10000
                                from: 0
                                to: 360
                                duration: 1200
                            }
                        }

                        Text {
                            anchors.fill: homePageImage
                            anchors.left: parent.left
                            anchors.leftMargin: 15
                            anchors.top: parent.top
                            anchors.topMargin: 5
                            color: "white"
                            font.pixelSize: 45
                            text: index + 1
                        }

                        Rectangle {
                            id: descriptionBG
                            anchors.fill: homePageImage
                            anchors.topMargin: homePageImage.height / 3 * 2
                            color: "black"
                            opacity: 0.3
                        }

                        Text {
                            id: nameText
                            anchors.left: descriptionBG.left
                            anchors.leftMargin: 13
                            anchors.top: descriptionBG.top
                            anchors.topMargin: 5
                            color: "white"
                            font.pixelSize: 25
                            text: elementName
                        }

                        Text {
                            anchors.left: nameText.left
                            anchors.top: nameText.bottom
                            font.pixelSize: 22
                            color: "white"
                            opacity: 0.8
                            text: elementSection
                        }
                    }
                }
            }

            ListView {
                id: homePageImageListView
                x: 14 * glValue.appUIWidth / 320
                y: 15
                width: pageContent.width - 2 * x
                height: 217 * glValue.appUIHeight / 640
                model: homePageImageModel
                delegate: homePageImageComponent
                orientation: Qt.Horizontal
                highlightRangeMode: ListView.StrictlyEnforceRange;
                snapMode: ListView.SnapOneItem
                boundsBehavior: Flickable.StopAtBounds
                clip: true
                cacheBuffer: {
                    if(glValue.currentPage == "home")
                        1
                    else
                        0
                }

                onContentXChanged: {
                    if(contentX % homePageImageListView.width === 0 ||
                            contentX % homePageImageListView.width === 0.5 ||
                            contentX % homePageImageListView.width === homePageImageListView.width-0.5)
                    {
                        //Reset all paginiation to light-off
                        for(i=0; i<pagniationListModel.count; i++)
                        {
                            pagniationListModel.get(i).elementSelected = 0
                        }

                        if(contentX % homePageImageListView.width === homePageImageListView.width-0.5)
                            pagniationListModel.get(contentX / (pageContent.width - homePageImageListView.x * 2 - 0.5)).elementSelected = 1
                        else
                            pagniationListModel.get(contentX / (pageContent.width - homePageImageListView.x * 2)).elementSelected = 1
                    }
                }
            }

            Image {
                id: pagniationBGImage
                x: 0
                y: 217 * glValue.appUIHeight / 640
                width: parent.width
                height: 31 * glValue.appUIHeight / 640
                opacity: 0.8
                source: "images/pagniation_bg.png"

                ListModel {
                    id: pagniationListModel
                }

                Component {
                    id: pagniationComponent

                    Item {
                        id: pagniationDelegateItem
                        width: 20 * glValue.appUIWidth / 360
                        height: 14 * glValue.appUIHeight/ 640
                        smooth: true

                        Image {
                            x: 0
                            y: 0
                            width: 13 * glValue.appUIWidth / 360
                            height: 14 * glValue.appUIHeight/ 640
                            source: {
                                if(elementSelected == 1)
                                    elementImageSelected
                                else
                                    elementImage
                            }
                        }
                    }
                }

                ListView {
                    id: pagniationListView
                    anchors.centerIn: parent
                    width: pagniationListModel.count * (20* glValue.appUIWidth / 360) - (7 * glValue.appUIHeight/ 640)
                    height: 14 * glValue.appUIHeight/ 640
                    model: pagniationListModel
                    delegate: pagniationComponent
                    orientation: Qt.Horizontal
                    interactive: false
                }
            }

            Image {
                id: imageCoverLeft
                x: 0
                y: 0
                width: 14 * glValue.appUIWidth / 320
                height: 300 * glValue.appUIHeight / 640
                source: "images/homePageImageCoverLeft.png"
            }

            Image {
                id: imageCoverRight
                x: parent.width - 14 * glValue.appUIWidth / 320
                y: 0
                width: 14 * glValue.appUIWidth / 320
                height: 300 * glValue.appUIHeight / 640
                source: "images/homePageImageCoverRight.png"
            }

            Image {
                x: 14
                y: 15
                width: 25
                height: 25
                source: "images/homePageImageLeftConner.png"
            }

            Image {
                x: glValue.appUIWidth - 14 - 25
                y: 15
                width: 25
                height: 25
                source: "images/homePageImageRightConner.png"
            }
        }

        states:
        [
            State
            {
                name: "show"
                PropertyChanges { target: container; x: 0; opacity: 1 }
            },
            State
            {
                name: "hideLeft"
                PropertyChanges { target: container; x: -pageContent.width; opacity: 1 }
            },
            State
            {
                name: "hideRight"
                PropertyChanges { target: container; x: pageContent.width; opacity: 1 }
            }
        ]
        transitions:
        [
            Transition {
                from: "show"; to: "hideLeft"
                PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
            },
            Transition {
                from: "hideLeft"; to: "show"
                PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
            },
            Transition {
                from: "show"; to: "hideRight"
                PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
            },
            Transition {
                from: "hideRight"; to: "show"
                PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
            }
        ]
    }
}
