import QtQuick 1.0

Item {
    id: nearbyList
    state: "hideLeft"

    //------------- Internal Globle Variable --------------------------
    property int i: 0

    //------------- Pages Moving Animation Control --------------------
    function showPageFromLeft()
    {
        nearbyList.state = "";
        nearbyList.state = "hideLeft"
        nearbyList.state = "show"
    }

    function showPageFromRight()
    {
        nearbyList.state = "";
        nearbyList.state = "hideRight"
        nearbyList.state = "show"
    }

    function hidePageToLeft()
    {
        nearbyList.state = "";
        nearbyList.state = "show"
        nearbyList.state = "hideLeft"
    }

    function hidePageToRight()
    {
        nearbyList.state = "";
        nearbyList.state = "show"
        nearbyList.state = "hideRight"
    }
    //----------------------- End ---------------------------------------

    function appendNearbyList(name, type, apiUrl)
    {
        loadingCover.hideLoadingCover();

        searchPageListModel.append(
                        {"elementID": searchPageListModel.count,
                         "elementType": type,
                         "elementName": name,
                         "elementApiUrl": apiUrl
        })
    }

    function resetData()
    {
        searchPageListModel.clear()
    }

    signal requireNearbyRestaurantDetail(string elementApiUrl)
    signal requireNearbyBarsClubsDetail(string elementApiUrl)

    Image {
        x: 14 * glValue.appUIWidth / 360
        y: 15 * glValue.appUIHeight / 640
        width: 332 * glValue.appUIWidth / 360
        height: 49 * glValue.appUIHeight / 640
        source: "images/filtlerBG.png"

        Text {
            anchors.fill: parent
            anchors.leftMargin: 15 * glValue.appUIWidth / 360
            font.pixelSize: 30
            font.bold: true
            verticalAlignment: Text.AlignVCenter
            color: "white"
            opacity: 0.8
            text: "Nearby"
        }
    }

    Item {
        id: pageContent
        x: 0
        y: 70 * glValue.appUIHeight / 640
        width: parent.width
        height: parent.height - y

        ListModel {
            id: searchPageListModel
        }

        Component {
            id: searchPageComponent

            Item {
                id: searchPageDelegateItem
                width: searchPageListView.width
                height: 70 * glValue.appUIHeight / 640
                smooth: true

                MouseArea{
                    anchors.fill: parent
                    onClicked: {
                        loadingCover.showLoadingCover();
                        sql.checkNearbyPageIfExisted()

                        if(elementType == "Restaurants")
                        {
                            restaurantsDetail.resetData()

                            requireNearbyRestaurantDetail(elementApiUrl)
                            restaurantsDetail.showPageFromRight()
                            nearbyList.hidePageToLeft()
                            nearbyList.resetData()

                            glValue.currentPage = "restaurantsDetail"
                            glValue.homeCurrentPage = "restaurantsDetail"

                        }
                        else if(elementType == "BarsClubs")
                        {
                            barsClubsDetail.resetData()

                            requireNearbyBarsClubsDetail(elementApiUrl)
                            barsClubsDetail.showPageFromRight()
                            nearbyList.hidePageToLeft()
                            nearbyList.resetData()

                            glValue.currentPage = "barsClubsDetail"
                            glValue.homeCurrentPage = "barsClubsDetail"
                        }
                    }
                }

                Image {
                    anchors.fill: parent
                    source: {
                        if(elementID === 0)
                            "images/listBGTop.png"
                        else if(elementID == searchPageListModel.count)
                            "images/listBGBottom.png"
                        else
                            "images/listBGFull.png"
                    }
                }

                Text {
                    anchors.fill: parent
                    anchors.leftMargin: 20 * glValue.appUIWidth / 360
                    anchors.rightMargin: 50 * glValue.appUIWidth / 360
                    verticalAlignment: Text.AlignVCenter
                    font.pixelSize: 30
                    color: "white"
                    opacity: 0.9
                    elide: Text.ElideRight
                    text: elementName
                }

                Image {
                    x: 0
                    y: 60 * glValue.appUIHeight / 640
                    width: parent.width
                    height: 5 * glValue.appUIHeight / 640
                    source: "images/listLine.png"
                }

                Image {
                    x: 290 * glValue.appUIWidth / 360
                    y: 18 * glValue.appUIHeight / 640
                    width: 27 * glValue.appUIWidth / 360
                    height: 32 * glValue.appUIHeight / 640
                    opacity: {
                        if(elementID == searchPageListModel.count)
                            0
                        else
                            1
                    }

                    source: "images/arrow.png"
                }
            }
        }

        ListView {
            id: searchPageListView
            anchors.fill: parent
            anchors.leftMargin: 15
            anchors.rightMargin: 15
            model: searchPageListModel
            delegate: searchPageComponent
            clip: true
        }
    }

    states:
    [
        State
        {
            name: "show"
            PropertyChanges { target: nearbyList; x: 0; opacity: 1 }
        },
        State
        {
            name: "hideLeft"
            PropertyChanges { target: nearbyList; x: -pageContent.width; opacity: 1 }
        },
        State
        {
            name: "hideRight"
            PropertyChanges { target: nearbyList; x: pageContent.width; opacity: 1 }
        }
    ]
    transitions:
    [
        Transition {
            from: "show"; to: "hideLeft"
            PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
        },
        Transition {
            from: "hideLeft"; to: "show"
            PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
        },
        Transition {
            from: "show"; to: "hideRight"
            PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
        },
        Transition {
            from: "hideRight"; to: "show"
            PropertyAnimation { properties: "x, opacity"; duration: 300; easing.type: Easing.InOutQuad }
        }
    ]
}
